import os
import shutil
import time
import pytest

from quixote import cleanup

from wcs.qommon.ident.password_accounts import PasswordAccount

from utilities import create_temporary_pub, clean_temporary_pub, get_app, login

def setup_module():
    clean_temporary_pub()


def teardown_module():
    pass


@pytest.fixture(scope='function')
def pub(request):
    pub = create_temporary_pub()
    def fin():
        shutil.rmtree(pub.APP_DIR)
    request.addfinalizer(fin)
    pub.cfg['identification'] = {'methods': ['password']}
    pub.cfg['misc'] = {'charset': 'utf-8'}
    pub.cfg['language'] = {'language': 'en'}
    pub.write_cfg()
    return pub


@pytest.fixture
def user(pub):
    user = pub.user_class()
    user.email = 'foo@localhost'
    user.store()
    account = PasswordAccount(id='foo')
    account.set_password('foo')
    account.user_id = user.id
    account.store()
    return user


@pytest.fixture
def app(pub):
    return get_app(pub)


def test_session_max_age(pub, user, app):
    with file(os.path.join(pub.app_dir, 'site-options.cfg'), 'w') as cfg:
        cfg.write('''[options]
session_max_age: 1
''')
    pub.load_site_options()

    login(app, username='foo', password='foo')
    assert 'Logout' in app.get('/')
    time.sleep(0.5)
    assert 'Logout' in app.get('/')
    time.sleep(0.6)
    assert 'Logout' not in app.get('/')

def test_session_expire(pub, user, app):
    login(app, username='foo', password='foo')
    assert 'Logout' in app.get('/')
    session = app.app.publisher.session_manager.session_class.select()[0]
    session.set_expire(time.time() + 10)
    session.store()
    assert 'Logout' in app.get('/')
    session.set_expire(time.time() - 1)
    session.store()
    assert 'Logout' not in app.get('/')
